@@ -2,7 +2,9 @@ from .structs import *
 from .server import Server
 from .interfaces import *
 from .utility import *
+from .backend import *
 from . import interfaces
 from . import utility
+from . import backend
 
-__version__ = '0.5.4'
+__version__ = '0.7.1'
